lapce_editor_core
library
Functions
-
autoDetectIndentStyle(RopeTextBuffer document)
→ IndentStyle?
-
-
charIsLineEnding(String character)
→ bool
-
-
charIsWhitespace(String character)
→ bool
-
-
classifyParagraphBoundary(ParagraphCharClassification beforePrevious, ParagraphCharClassification previous, ParagraphCharClassification next, ParagraphCharClassification afterNext)
→ ParagraphBoundary
-
-
classifyWordBoundary(WordCharClassification previous, WordCharClassification next)
→ WordBoundary
-
-
countSpacesFrom(RopeTextBuffer text, TextOffset offset)
→ int
-
-
createIndentEdit(RopeTextBuffer buffer, TextOffset offset, String indent)
→ (Selection, String)
-
-
createOutdentEdit(RopeTextBuffer buffer, TextOffset offset, String indent)
→ (Selection, String)?
-
-
determineLineEnding(String text)
→ LineEndingDetermination
-
-
determineLineEndingChunks(Iterable<String> chunks)
→ LineEndingDetermination
-
Reproduces xi-rope's chunk-based detection: each chunk contributes the
kind of its first newline, and different kinds across chunks are mixed.
-
expandDiffLines(List<DiffLines> lines, int line, DiffExpand expand, {required bool isRight})
→ void
-
-
formatStartEnd(RopeTextBuffer buffer, TextRange range, {required bool isVertical, required bool firstNonBlank, required int count})
→ TextRange
-
-
getFirstSelectionAfter(Cursor cursor, RopeTextBuffer buffer, DeltaMap delta)
→ Cursor?
-
-
hasUnmatchedPair(String line)
→ bool
-
-
lineEndingOr(LineEndingDetermination determination, LineEnding fallback)
→ LineEnding
-
-
matchingBracketGeneral(String character)
→ String?
-
Dart strings are the shared representation for both Rust
char and str.
-
matchingCharacter(String character)
→ String?
-
Returns the bracket paired with
character.
-
matchingPairDirection(String character)
→ bool?
-
Whether
character opens (true) or closes (false) a supported pair.
-
paragraphCharacterProperty(String character)
→ ParagraphCharClassification
-
-
parseModes(String value)
→ Set<Mode>
-
-
regionToRange(SelectionRegion region)
→ TextRange
-
-
ropeDiff(String left, String right, {int? contextLines, bool isCurrent()?})
→ List<DiffLines>?
-
-
snapToSoftTab(RopeTextBuffer text, TextOffset offset, SnapDirection direction, int tabWidth)
→ TextOffset
-
-
snapToSoftTabLineColumn(RopeTextBuffer text, int line, int column, SnapDirection direction, int tabWidth)
→ int
-
-
snapToSoftTabLogic(RopeTextBuffer text, int offsetOrColumn, TextOffset lineStart, SnapDirection direction, int tabWidth)
→ int
-
-
stringIsPairLeft(String value)
→ bool
-
-
stringMatchingPair(String value)
→ String?
-
-
wordCharacterProperty(String character)
→ WordCharClassification
-